`timescale 1ps / 1ps
//*****************************************************************************
// File Name            : stepper_motor_ap.v
//-----------------------------------------------------------------------------
// Function             : unipolar stepper motor controller
//                        
//-----------------------------------------------------------------------------
// Designer             : yokomizo 
//-----------------------------------------------------------------------------
// History
// -.-- 2014/9/02@a
//*****************************************************************************

module stepper_motor_ap (
  clk,
  rstb,
  uart_txd,uart_rxd,
  busy_0,m_a_0,m_a_b_0,m_b_0,m_b_b_0,
  busy_1,m_a_1,m_a_b_1,m_b_1,m_b_b_1,
  busy_2,m_a_2,m_a_b_2,m_b_2,m_b_b_2,
  busy_3,m_a_3,m_a_b_3,m_b_3,m_b_b_3
);

  input clk;
  input rstb;
  output uart_txd;
  input uart_rxd;  
  output busy_0,m_a_0,m_a_b_0,m_b_0,m_b_b_0;
  output busy_1,m_a_1,m_a_b_1,m_b_1,m_b_b_1;
  output busy_2,m_a_2,m_a_b_2,m_b_2,m_b_b_2;
  output busy_3,m_a_3,m_a_b_3,m_b_3,m_b_b_3;
  
  wire [31:0] gpo_1;
  wire [31:0] gpo_2;
  wire [7:0] gpo_3;
  wire [7:0] gpi_1;
  
   //vZbT 
   nios2_e nios2_e(
		.clk_clk(clk),        //   clk.clk
		.reset_reset_n(rstb), // reset.reset_n
		.uart_rxd(uart_rxd),  //  uart.rxd
		.uart_txd(uart_txd),  //      .txd
	    .gpo_1_export(gpo_1), // gpo_1.export
		.gpo_2_export(gpo_2), // gpo_2.export
		.gpo_3_export(gpo_3), // gpo_3.export
		.gpi_1_export(gpi_1)  // gpi_1.export
	);
	
	assign gpi_1 ={4'b0000,busy_3,busy_2,busy_1,busy_0};	
	
   //[^H_0
	stepper_motor_uni m_0 (
		.clk(clk), 
		.rstb(rstb), 
		.start(gpo_3[0]),  
		.en(gpo_1[0]), 
		.cw(gpo_1[1]),  
		.step_t(gpo_1[7:4]),  
		.step_n(gpo_1[15:8]),  
		.busy(busy_0),
		.m_a(m_a_0),
		.m_a_b(m_a_b_0),
		.m_b(m_b_0),
		.m_b_b(m_b_b_0)
	);
   //[^H_1	
	stepper_motor_uni m_1 (
		.clk(clk), 
		.rstb(rstb), 
		.start(gpo_3[1]),  
		.en(gpo_1[16]), 
		.cw(gpo_1[17]),  
		.step_t(gpo_1[23:20]),  
		.step_n(gpo_1[31:24]),  
		.busy(busy_1),
		.m_a(m_a_1),
		.m_a_b(m_a_b_1),
		.m_b(m_b_1),
		.m_b_b(m_b_b_1)
	);
   //[^H_2	
	stepper_motor_uni m_2 (
		.clk(clk), 
		.rstb(rstb), 
		.start(gpo_3[2]),  
		.en(gpo_2[0]), 
		.cw(gpo_2[1]),  
		.step_t(gpo_2[7:4]),  
		.step_n(gpo_2[15:8]),  
		.busy(busy_2),
		.m_a(m_a_2),
		.m_a_b(m_a_b_2),
		.m_b(m_b_2),
		.m_b_b(m_b_b_2)
	);
   //[^H_3	
	stepper_motor_uni m_3 (
		.clk(clk), 
		.rstb(rstb), 
		.start(gpo_3[3]),  
		.en(gpo_2[16]), 
		.cw(gpo_2[17]),  
		.step_t(gpo_2[23:20]),  
		.step_n(gpo_2[31:24]),  
		.busy(busy_3),
		.m_a(m_a_3),
		.m_a_b(m_a_b_3),
		.m_b(m_b_3),
		.m_b_b(m_b_b_3)
	);
	
endmodule






